@@ -14,6 +14,7 @@ from pydocx.utils import (
     find_ancestor_with_tag,
     has_descendant_with_tag,
 )
+from pydocx.exceptions import MalformedDocxException
 
 logging.basicConfig(level=logging.DEBUG)
 logger = logging.getLogger("NewParser")
@@ -30,14 +31,17 @@ JUSTIFY_RIGHT = 'right'
 INDENTATION_RIGHT = 'right'
 INDENTATION_LEFT = 'left'
 INDENTATION_FIRST_LINE = 'firstLine'
-DISABLED_VALUES = ['false', '0']
+DISABLED_VALUES = ['false', '0', 'none']
 
 # Add some helper functions to Element to make it slightly more readable
 
 
 @contextmanager
 def ZipFile(path):  # This is not needed in python 3.2+
-    f = zipfile.ZipFile(path)
+    try:
+        f = zipfile.ZipFile(path)
+    except zipfile.BadZipfile:
+        raise MalformedDocxException('Passed in document is not a docx')
     yield f
     f.close()
 
