@@ -1,12 +1,14 @@
 import base64
-
 from os import path
+from tempfile import NamedTemporaryFile
 
 from nose.plugins.skip import SkipTest
+from nose.tools import raises
 
 from pydocx.tests import assert_html_equal, BASE_HTML
 from pydocx.parsers.Docx2Html import Docx2Html
 from pydocx.DocxParser import ZipFile
+from pydocx.exceptions import MalformedDocxException
 
 
 def convert(path, *args, **kwargs):
@@ -735,6 +737,26 @@ def test_missing_style():
     ''')
 
 
+def test_missing_numbering():
+    file_path = path.join(
+        path.abspath(path.dirname(__file__)),
+        '..',
+        'fixtures',
+        'missing_numbering.docx',
+    )
+    actual_html = convert(file_path)
+    assert_html_equal(actual_html, BASE_HTML % '''
+    <p>AAA</p>
+    <p>BBB</p>
+    ''')
+
+
+@raises(MalformedDocxException)
+def test_malformed_docx_exception():
+    with NamedTemporaryFile(suffix='.docx') as f:
+        convert(f.name)
+
+
 def _converter(*args, **kwargs):
     # Having a converter that does nothing is the same as if abiword fails to
     # convert.
